@@ -59,7 +59,7 @@
 
 #ifndef __pce_export
 #if defined(PCE_INCLUDED) && (defined(WIN32) || defined(__CYWIN32__))
-#define __pce_export __declspec(dllexport)
+#define __pce_export __declspec(dllexport) extern
 #else
 #define __pce_export extern
 #endif /*PCE_INCLUDED*/
@@ -396,7 +396,7 @@ __pce_export int pceSetProfileHooks(pce_profile_hooks *hooks);
 		*         INITIALISATION	*
 		********************************/
 
-__pce_export int pceInitialise(int handles, const char *home,
+__pce_export int pceInitialise(int handles, const char *home, const char *appdata,
 			       int argc, char **argv);
 
 
