@@ -33,9 +33,11 @@
     POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include "pl-incl.h"
-#include <ctype.h>
 #include "pl-ctype.h"
+#include "pl-text.h"
+#include "../pl-read.h"
+#include "../pl-fli.h"
+#include <ctype.h>
 #include <errno.h>
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
