@@ -3,7 +3,7 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2012-2018, VU University Amsterdam
+    Copyright (c)  2012-2020, VU University Amsterdam
 			      CWI, Amsterdam
     All rights reserved.
 
@@ -91,6 +91,8 @@ COMMON(void)	free_lingering(linger_list **list, gen_t generation);
 		 *******************************/
 
 COMMON(void)		initAlloc(void);
+COMMON(int)		initTCMalloc(void);
+COMMON(size_t)		heapUsed(void);
 #ifndef DMALLOC
 COMMON(void *)		allocHeap(size_t n);
 COMMON(void *)		allocHeapOrHalt(size_t n);
@@ -117,11 +119,42 @@ COMMON(int)		put_int64(Word p, int64_t i, int flags ARG_LD);
 COMMON(int64_t)		valBignum__LD(word w ARG_LD);
 #endif
 COMMON(int)		equalIndirect(word r1, word r2);
-COMMON(size_t)		gsizeIndirectFromCode(Code PC);
+ALLOC_INLINE(size_t)	gsizeIndirectFromCode(Code PC);
 COMMON(word)		globalIndirectFromCode(Code *PC);
+COMMON(void *)		tmp_malloc(size_t req);
+COMMON(void *)		tmp_realloc(void *mem, size_t req);
+COMMON(void)		tmp_free(void *mem);
+COMMON(size_t)		tmp_nalloc(size_t req);
+COMMON(size_t)		tmp_nrealloc(void *mem, size_t req);
+COMMON(void *)		stack_malloc(size_t req);
+COMMON(void *)		stack_realloc(void *mem, size_t req);
+COMMON(void)		stack_free(void *mem);
+COMMON(size_t)		stack_nalloc(size_t req);
+COMMON(size_t)		stack_nrealloc(void *mem, size_t req);
 #ifndef xmalloc
 COMMON(void *)		xmalloc(size_t size);
 COMMON(void *)		xrealloc(void *mem, size_t size);
 #endif
+#if USE_ALLOC_INLINES || EMIT_ALLOC_INLINES
+struct word_and_Code {
+	word word;
+	Code code;
+};
+#define WORD_AND_CODE(w,c) ((struct word_and_Code){(w),(c)})
+
+ALLOC_INLINE(struct word_and_Code)
+			VM_globalIndirectFromCode(Code pc ARG_LD);
+ALLOC_INLINE(struct word_and_Code)
+			VM_equalIndirectFromCode(word a, Code pc ARG_LD);
+#endif
+
+		 /*******************************
+		 *	LD-USING FUNCTIONS	*
+		 *******************************/
+
+#define allocGlobal(n)		allocGlobal__LD(n PASS_LD)
+#define allocGlobalNoShift(n)	allocGlobalNoShift__LD(n PASS_LD)
+#define getCharsString(s, l)	getCharsString__LD(s, l PASS_LD)
+#define getCharsWString(s, l)	getCharsWString__LD(s, l PASS_LD)
 
 #endif /*PL_ALLOC_H_INCLUDED*/
