@@ -34,7 +34,12 @@
 */
 
 /*#define O_DEBUG 1*/
-#include "pl-incl.h"
+#include "pl-atom.h"
+#include "pl-setup.h"
+#include "pl-gc.h"
+#include "pl-fli.h"
+#include "pl-pro.h"
+#include "pl-read.h"
 #include "os/pl-ctype.h"
 #undef LD
 #define LD LOCAL_LD
@@ -771,7 +776,7 @@ markAtom(atom_t a)
   }
 }
 
-void
+static void
 unmarkAtoms(void)
 { size_t index;
   int i, last=FALSE;
@@ -797,7 +802,7 @@ unmarkAtoms(void)
 }
 
 
-void
+static void
 maybe_free_atom_tables(void)
 {
   AtomTable t = GD->atoms.table;
