@@ -34,8 +34,12 @@
 */
 
 /*#define O_DEBUG 1*/
-#include "pl-incl.h"
-#include "pl-inline.h"
+#include "pl-attvar.h"
+#include "pl-wam.h"
+#include "pl-gc.h"
+#include "pl-write.h"
+#include "pl-prims.h"
+#include "pl-fli.h"
 #ifdef O_ATTVAR
 
 #undef LD
@@ -85,8 +89,6 @@ PL_get_attr__LD(term_t t, term_t a ARG_LD)
   fail;
 }
 
-#define PL_get_attr(t, a) PL_get_attr__LD(t, a PASS_LD)
-
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 (*) Although this is an assignment from var   to value, we use a trailed
 assignment  to  exploit  mergeTrailedAssignments()   in  GC,  discarding
