@@ -33,9 +33,15 @@
     POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include "pl-incl.h"
+#include "pl-cont.h"
 #include "pl-comp.h"
 #include "pl-dbref.h"
+#include "pl-util.h"
+#include "pl-gc.h"
+#include "pl-wam.h"
+#include "pl-pro.h"
+#include "pl-fli.h"
+#include "pl-modul.h"
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Implementation of `delimited continuation'.  Implements
@@ -546,9 +552,6 @@ retry:
     enterDefinition(fr->predicate);
     environment_frame = fr;
 
-    if ( strcmp(predicateName(fr->predicate), "make_wrapper__/2") == 0 )
-      trap_gdb();
-
     DEBUG(MSG_CONTINUE,
 	  Sdprintf("Resume clause %d of %s at PC=%ld\n",
 		   clauseNo(cl, 0),
