@@ -34,7 +34,10 @@
 */
 
 /*#define O_DEBUG 1*/
-#include "pl-incl.h"
+#include "pl-gvar.h"
+#include "pl-gc.h"
+#include "pl-wam.h"
+#include "pl-prims.h"
 #ifdef O_GVAR
 
 
