@@ -33,9 +33,13 @@
     POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include "pl-incl.h"
+#include "pl-index.h"
 #include "pl-comp.h"
 #include "pl-rsort.h"
+#include "pl-util.h"
+#include "pl-proc.h"
+#include "pl-fli.h"
+#include "pl-wam.h"
 #include <math.h>
 
 		 /*******************************
