@@ -45,6 +45,24 @@ option  parsing,  initialisation  and  handling  of errors and warnings.
 #include "pl-arith.h"
 #include "pl-zip.h"
 #include "pl-prof.h"
+#include "pl-read.h"
+#include "pl-prims.h"
+#include "pl-setup.h"
+#include "pl-fli.h"
+#include "pl-wic.h"
+#include "pl-pro.h"
+#include "pl-trace.h"
+#include "pl-proc.h"
+#include "pl-modul.h"
+#include "pl-flag.h"
+#include "pl-rec.h"
+#include "pl-term.h"
+#include "pl-funct.h"
+#include "pl-ext.h"
+#include "pl-srcfile.h"
+#include "pl-load.h"
+#include "pl-nt.h"
+#include "os/pl-prologflag.h"
 #include "os/pl-ctype.h"
 #include "os/pl-utf8.h"
 #include <errno.h>
@@ -1370,7 +1388,7 @@ struct on_halt
   OnHalt	next;
 };
 
-void
+static void
 register_halt(OnHalt *where, halt_function f, void *arg)
 { if ( !GD->os.halting )
   { OnHalt h = allocHeapOrHalt(sizeof(struct on_halt));
