@@ -51,6 +51,7 @@
 #endif
 
 #include "pl-transaction.h"
+#include "pl-atom.h"
 
 
 		 /*******************************
@@ -376,7 +377,6 @@ popcount_bitvector(const bit_vector *v)
 		 *******************************/
 
 static int	  same_type_numbers(Number n1, Number n2) WUNUSED;
-static Definition lookupDefinition(functor_t f, Module m) WUNUSED;
 
 static inline int
 same_type_numbers(Number n1, Number n2)
@@ -385,14 +385,6 @@ same_type_numbers(Number n1, Number n2)
   return make_same_type_numbers(n1, n2);
 }
 
-
-static inline Definition
-lookupDefinition(functor_t f, Module m)
-{ Procedure proc = lookupProcedure(f, m);
-
-  return proc ? proc->definition : NULL;
-}
-
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Mark() sets LD->mark_bar, indicating  that   any  assignment  above this
 value need not be trailed.
@@ -410,26 +402,8 @@ Trail__LD(Word p, word v ARG_LD)
 }
 
 
-static inline void
-bindConst__LD(Word p, word c ARG_LD)
-{ DEBUG(0, assert(hasGlobalSpace(0)));
-
-#ifdef O_ATTVAR
-  if ( isVar(*p) )
-  { *p = (c);
-    if ( (void*)p >= (void*)lBase || p < LD->mark_bar )
-      (tTop++)->address = p;
-  } else
-  { assignAttVar(p, &(c) PASS_LD);
-  }
-#else
-  *p = (c);
-  if ( (void*)p >= (void*)lBase || p < LD->mark_bar )
-    (tTop++)->address = p;
-#endif
-}
-
-
+#define consPtrB(p, base, ts)	consPtr__LD(p, (uintptr_t)(base), (ts) PASS_LD)
+#define consPtr(p, ts)		consPtrB(p, LD->bases[(ts)&STG_MASK], (ts))
 static inline word
 consPtr__LD(void *p, uintptr_t base, word ts ARG_LD)
 { uintptr_t v = (uintptr_t) p;
@@ -458,6 +432,7 @@ checking (unless compiled for debugging) and fetches the base address of
 the global stack only once.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
+#define linkValI(p)		linkValI__LD(p PASS_LD)
 static inline word
 linkValI__LD(Word p ARG_LD)
 { word w = *p;
@@ -596,31 +571,6 @@ setGenerationFrame__LD(LocalFrame fr ARG_LD)
   }
 }
 
-static inline int
-ensureLocalSpace__LD(size_t bytes ARG_LD)
-{ int rc;
-
-  if ( likely(addPointer(lTop, bytes) <= (void*)lMax) )
-    return TRUE;
-
-  if ( (rc=growLocalSpace__LD(bytes, ALLOW_SHIFT PASS_LD)) == TRUE )
-    return TRUE;
-
-  return raiseStackOverflow(rc);
-}
-
-static inline int
-ensureStackSpace__LD(size_t gcells, size_t tcells, int flags ARG_LD)
-{ gcells += BIND_GLOBAL_SPACE;
-  tcells += BIND_TRAIL_SPACE;
-
-  if ( likely(gTop+gcells <= gMax) && likely(tTop+tcells <= tMax) )
-    return TRUE;
-
-  return f_ensureStackSpace__LD(gcells, tcells, flags PASS_LD);
-}
-
-
 		 /*******************************
 		 *	      THREADS		*
 		 *******************************/
