@@ -34,8 +34,15 @@
     POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include "pl-incl.h"
+#include "pl-modul.h"
 #include "pl-comp.h"
+#include "pl-util.h"
+#include "pl-proc.h"
+#include "pl-funct.h"
+#include "pl-srcfile.h"
+#include "pl-fli.h"
+#include "pl-prims.h"
+#include "pl-wam.h"
 #undef LD
 #define LD LOCAL_LD
 
@@ -1065,7 +1072,7 @@ PRED_IMPL("$current_source_module", 1, current_source_module, 0)
   return PL_unify_atom(A1, LD->modules.source->name);
 }
 
-
+static
 PRED_IMPL("$set_source_module", 1, set_source_module, 0)
 { PRED_LD
   atom_t name;
