@@ -34,8 +34,10 @@
     POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include "pl-incl.h"
+#include "pl-mutex.h"
 #include "pl-thread.h"
+#include "pl-fli.h"
+#include "pl-pro.h"
 
 #undef LD
 #define LD LOCAL_LD
