@@ -37,11 +37,18 @@
 #ifdef SECURE_GC
 #define O_DEBUG 1			/* include checkData() */
 #endif
-#include "pl-incl.h"
+#include "pl-pro.h"
 #include "pl-arith.h"
 #include "os/pl-cstack.h"
+#include "os/pl-ctype.h"
 #include "pl-event.h"
 #include "pl-tabling.h"
+#include "pl-trace.h"
+#include "pl-setup.h"
+#include "pl-wam.h"
+#include "pl-attvar.h"
+#include "pl-proc.h"
+#include "pl-fli.h"
 
 
 		/********************************
