@@ -35,13 +35,18 @@
 */
 
 /*#define O_DEBUG 1*/
-#include "pl-incl.h"
+#include "pl-rec.h"
 #include "pl-comp.h"
 #include "pl-arith.h"
 #include "pl-dbref.h"
 #include "pl-termwalk.c"
 #include "pl-dict.h"
 #include "pl-event.h"
+#include "pl-fli.h"
+#include "pl-pro.h"
+#include "pl-funct.h"
+#include "pl-gc.h"
+#include "pl-proc.h"
 
 #define WORDS_PER_PLINT (sizeof(int64_t)/sizeof(word))
 
@@ -1769,7 +1774,7 @@ markAtomsRecord(Record record)
 
 
 #ifdef O_DEBUG_ATOMGC
-void
+static void
 unregister_atom_rec(atom_t a)
 { PL_unregister_atom(a);
 }
