@@ -36,15 +36,31 @@
 
 /*#define O_DEBUG 1*/
 
-#define GLOBAL SO_LOCAL			/* allocate global variables here */
-#include "pl-incl.h"
+#define GLOBAL			/* allocate global variables here */
+#include "pl-setup.h"
 #include "pl-comp.h"
 #include "pl-arith.h"
 #include "os/pl-cstack.h"
+#include "os/pl-ctype.h"
+#include "os/pl-prologflag.h"
 #include "pl-dbref.h"
 #include "pl-trie.h"
 #include "pl-tabling.h"
 #include "pl-undo.h"
+#include "pl-fli.h"
+#include "pl-funct.h"
+#include "pl-modul.h"
+#include "pl-rec.h"
+#include "pl-flag.h"
+#include "pl-ext.h"
+#include "pl-op.h"
+#include "pl-trace.h"
+#include "pl-read.h"
+#include "pl-wam.h"
+#include "pl-gc.h"
+#include "pl-proc.h"
+#include "pl-pro.h"
+#include "pl-gvar.h"
 #include <sys/stat.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
