@@ -35,11 +35,17 @@
 */
 
 /*#define O_DEBUG 1*/
-#include "pl-incl.h"
+#include "pl-srcfile.h"
 #include "pl-comp.h"
 #include "pl-dbref.h"
 #include "pl-event.h"
 #include "pl-tabling.h"
+#include "pl-setup.h"
+#include "pl-util.h"
+#include "pl-proc.h"
+#include "pl-fli.h"
+#include "pl-modul.h"
+#include "pl-supervisor.h"
 
 static void	fix_ssu(p_reload *r, Clause clause);
 
@@ -1011,7 +1017,7 @@ reloadHasClauses(SourceFile sf, Procedure proc ARG_LD)
 }
 
 
-int
+static int
 isRedefinedProcedure(Procedure proc, gen_t gen)
 { GET_LD
   Definition def = proc->definition;
