@@ -205,6 +205,8 @@ typedef struct idg_node
   unsigned	lazy_queued : 1;	/* There are answers queued */
   unsigned	force_reeval : 1;	/* Forced reevaluation for monotonic */
   unsigned	mono_reevaluating : 1;	/* Monotonic reevaluation in progress */
+  unsigned	tt_notrail : 1;		/* Do not trail new monotonic answers */
+  unsigned	tt_new_dep : 1;		/* New dependency on transition mod */
   int		falsecount;		/* Invalidate count */
 #ifdef O_TRIE_STATS
   struct
@@ -241,13 +243,15 @@ typedef struct trie_array
 		 *    TRANSACTION RECORDING	*
 		 *******************************/
 
+#define TT_TBL_INVALIDATE	0x001
+
 typedef struct tbl_trail
-{ buffer	actions;
+{ Table		tables;			/* Affected tables */
+  buffer	actions;
 } tbl_trail;
 
 typedef enum tbl_trail_type
-{ TT_TABLE,
-  TT_ANSWER
+{ TT_ANSWER = 1
 } tbl_trail_type;
 
 typedef struct tbl_trail_any
