@@ -34,12 +34,24 @@
     POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include "pl-incl.h"
+#include "pl-trace.h"
 #include "pl-comp.h"
 #include "os/pl-ctype.h"
 #include "os/pl-cstack.h"
 #include "pl-inline.h"
 #include "pl-dbref.h"
+#include "pl-fli.h"
+#include "pl-gc.h"
+#include "pl-rec.h"
+#include "pl-prims.h"
+#include "pl-attvar.h"
+#include "pl-pro.h"
+#include "pl-util.h"
+#include "pl-wam.h"
+#include "pl-write.h"
+#include "pl-setup.h"
+#include "pl-proc.h"
+#include "os/pl-prologflag.h"
 #include <stdio.h>
 
 #define WFG_TRACING	0x02000
@@ -1517,7 +1529,6 @@ loffset(void *p)
   return (Word)p-(Word)lBase;
 }
 
-extern char *chp_chars(Choice ch);
 #endif
 
 static LocalFrame
