@@ -39,6 +39,15 @@
 #include "pl-trie.h"
 #include "pl-tabling.h"
 #include "pl-indirect.h"
+#include "pl-proc.h"
+#include "pl-prims.h"
+#include "pl-wam.h"
+#include "pl-gc.h"
+#include "pl-fli.h"
+#include "pl-rec.h"
+#include "pl-util.h"
+#include "pl-attvar.h"
+#include "pl-pro.h"
 #define NO_AC_TERM_WALK 1
 #define AC_TERM_WALK_POP 1
 #include "pl-termwalk.c"
@@ -1945,7 +1954,7 @@ mask such that  we  perform  a  couple   of  hash  lookups  rather  than
 enumerating the entire table.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-trie_choice *
+static trie_choice *
 add_choice(trie_gen_state *state, descent_state *dstate, trie_node *node ARG_LD)
 { trie_children children = node->children;
   trie_choice *ch;
