@@ -36,12 +36,23 @@
 */
 
 /*#define O_DEBUG 1*/
-#include "pl-incl.h"
+#include "pl-wic.h"
 #include "pl-comp.h"
 #include "pl-arith.h"
 #include "os/pl-utf8.h"
 #include "pl-dbref.h"
 #include "pl-dict.h"
+#include "pl-funct.h"
+#include "pl-proc.h"
+#include "pl-util.h"
+#include "pl-modul.h"
+#include "pl-srcfile.h"
+#include "pl-pro.h"
+#include "pl-fli.h"
+#include "pl-prims.h"
+#include "pl-write.h"
+#include "pl-read.h"
+#include "os/pl-ctype.h"
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
@@ -2127,7 +2138,7 @@ freeXRSymbol(void *name, void *value)
 }
 
 
-void
+static void
 initXR(wic_state *state)
 { state->currentPred		   = NULL;
   state->currentSource		   = NULL;
@@ -2137,7 +2148,7 @@ initXR(wic_state *state)
 }
 
 
-void
+static void
 destroyXR(wic_state *state)
 { destroyHTable(state->savedXRTable);
   state->savedXRTable = NULL;
